/*
   Copyright (C) 2003 Lars Lindner <lars.lindner@gmx.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <gdk/gdk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "backend.h"
#include "htmlview.h"
#include "conf.h"

GtkWidget	*mainwindow;
GtkWidget	*newdialog = NULL;
GtkWidget	*feednamedialog = NULL;
GtkWidget	*propdialog = NULL;
GtkWidget	*aboutdialog = NULL;
GtkWidget	*prefdialog = NULL;
GtkWidget	*feedlistdialog = NULL;

extern GtkTreeIter	*myfeedgroup;
extern GtkTreeIter	*availablefeedgroup;

extern GdkPixbuf	*unreadIcon;
extern GdkPixbuf	*readIcon;


gpointer getFeedViewSelection(GtkWidget *feedlist) {
	GtkTreeSelection	*select;
        GtkTreeModel		*model;
	GtkTreeIter		iter;	
	gpointer		cp = NULL;
		
	if(NULL == feedlist) {
		print_status(_("could not find feed list widget!"));
		return NULL;
	}
			
	if(NULL == (select = gtk_tree_view_get_selection(GTK_TREE_VIEW(feedlist)))) {
		print_status(_("could not retrieve selection of feed list!"));
		return NULL;
	}

        if(gtk_tree_selection_get_selected (select, &model, &iter))
                gtk_tree_model_get(model, &iter, FS_CP, &cp, -1);
	else {
		print_status(_("could not retrieve selected list entry!"));
		return NULL;
	}
	
	return cp;
}

void selectFeedViewItem(GtkWidget *window, gchar *viewname, gpointer cp) {
	GtkWidget		*view;
	GtkTreeSelection	*select;
        GtkTreeModel		*model;
	GtkTreeIter		iter;
	GtkTreeStore		*feedstore;	
	gboolean		valid;
	gpointer		tmp_cp;
		
	if(NULL == window) {
		g_warning(_("feed list window not available!\n"));
		return;	
	}
	
	if(NULL == (view = lookup_widget(window, viewname))) {
		g_warning(_("feed list widget lookup failed!\n"));
		return;
	}
		
	if(NULL == (select = gtk_tree_view_get_selection(GTK_TREE_VIEW(view)))) {
		g_warning(_("could not retrieve selection of feed list!\n"));
		return;
	}

	feedstore = getFeedStore();
	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(feedstore), &iter);
	while(valid) {
		gtk_tree_model_get(GTK_TREE_MODEL(feedstore), &iter, FS_CP, &tmp_cp, -1);
		      
		if(tmp_cp == cp) {
			gtk_tree_selection_select_iter(select, &iter);
			break;
		}	

		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(feedstore), &iter);
	}
}

void on_refreshbtn_clicked(GtkButton *button, gpointer user_data) {
	gpointer	cp;
	
	if(NULL != (cp = getFeedViewSelection(lookup_widget(mainwindow, "feedlist"))))
		updateFeed(cp);
}

void on_popup_refresh_selected(void) {
	gpointer	cp;
	
	if(NULL != (cp = getFeedViewSelection(lookup_widget(mainwindow, "feedlist"))))
		updateFeed(cp);
}

void on_feedlistbtn_clicked(GtkButton *button, gpointer user_data) {
	GtkWidget		*flview;
	GtkCellRenderer		*renderer;
	GtkTreeViewColumn 	*column;
	GtkTreeSelection	*select;	
	GtkTreeIter		*iter;
	GtkTreeStore		*feedstore;
	
	if(NULL == feedlistdialog || !G_IS_OBJECT(feedlistdialog)) {
		feedlistdialog = create_feedlistdialog();		

		/* setup feed list view */
		feedstore = getFeedStore();
		flview = lookup_widget(feedlistdialog, "feedlist");
		
		gtk_tree_view_set_model(GTK_TREE_VIEW(flview), GTK_TREE_MODEL(feedstore));			

		renderer = gtk_cell_renderer_text_new();
		column = gtk_tree_view_column_new_with_attributes(_("Title"), renderer, "text", FS_TITLE, NULL);
		gtk_tree_view_append_column(GTK_TREE_VIEW(flview), column);	
		gtk_tree_view_column_set_sort_column_id(column, FS_TITLE);

		renderer = gtk_cell_renderer_text_new();	
		column = gtk_tree_view_column_new_with_attributes(_("URL"), renderer, "text", FS_URL, NULL);	
		gtk_tree_view_append_column(GTK_TREE_VIEW(flview), column);
		gtk_tree_view_column_set_sort_column_id(column, FS_URL);		
	}

	gtk_widget_show(feedlistdialog);
}

void on_prefbtn_clicked(GtkButton *button, gpointer user_data) {
	GtkWidget	*browsercmdentry, 
			*timeformatentry,
			*proxyhostentry,
			*proxyportentry,
			*useproxycheck,
			*dccheck,
			*contentcheck,
			*slashcheck;
				
	if(NULL == prefdialog || !G_IS_OBJECT(prefdialog))
		prefdialog = create_prefdialog ();		

	// FIXME: bad solution, design a generic pref interface!
	browsercmdentry = lookup_widget(prefdialog, "browsercmd");
	timeformatentry = lookup_widget(prefdialog, "timeformat");
	proxyhostentry = lookup_widget(prefdialog, "proxyhost");
	proxyportentry = lookup_widget(prefdialog, "proxyport");
	useproxycheck =  lookup_widget(prefdialog, "useproxy");
	dccheck =  lookup_widget(prefdialog, "usedc");
	contentcheck =  lookup_widget(prefdialog, "usecontent");
	slashcheck =  lookup_widget(prefdialog, "useslash");
		
	gtk_entry_set_text(GTK_ENTRY(browsercmdentry), getStringConfValue(BROWSER_COMMAND));
	gtk_entry_set_text(GTK_ENTRY(timeformatentry), getStringConfValue(TIME_FORMAT));
	gtk_entry_set_text(GTK_ENTRY(proxyhostentry), getStringConfValue(PROXY_HOST));
	gtk_entry_set_text(GTK_ENTRY(proxyportentry), g_strdup_printf("%d", getNumericConfValue(PROXY_PORT)));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(useproxycheck), getBooleanConfValue(USE_PROXY));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dccheck), getBooleanConfValue(USE_DC));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(contentcheck), getBooleanConfValue(USE_CONTENT));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(slashcheck), getBooleanConfValue(USE_SLASH));
				
	gtk_widget_show(prefdialog);
}

void on_prefsavebtn_clicked(GtkButton *button, gpointer user_data) {
	GtkWidget	*browsercmdentry, 
			*timeformatentry,
			*proxyhostentry,
			*proxyportentry,
			*useproxycheck,
			*dccheck,
			*contentcheck,
			*slashcheck;

	// FIXME: bad solution, design a generic pref interface!
	browsercmdentry = lookup_widget(prefdialog, "browsercmd");
	timeformatentry = lookup_widget(prefdialog, "timeformat");
	proxyhostentry = lookup_widget(prefdialog, "proxyhost");
	proxyportentry = lookup_widget(prefdialog, "proxyport");
	useproxycheck =  lookup_widget(prefdialog, "useproxy");
	dccheck =  lookup_widget(prefdialog, "usedc");
	contentcheck =  lookup_widget(prefdialog, "usecontent");
	slashcheck =  lookup_widget(prefdialog, "useslash");
		
	setStringConfValue(BROWSER_COMMAND,
			   (gchar *)gtk_entry_get_text(GTK_ENTRY(browsercmdentry)));
	setStringConfValue(TIME_FORMAT,
			   (gchar *)gtk_entry_get_text(GTK_ENTRY(timeformatentry)));
	setStringConfValue(PROXY_HOST,
			   (gchar *)gtk_entry_get_text(GTK_ENTRY(proxyhostentry)));
	setNumericConfValue(PROXY_PORT,
			   atoi(gtk_entry_get_text(GTK_ENTRY(proxyportentry))));
	setBooleanConfValue(USE_PROXY,
			   (gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(useproxycheck)));
	setBooleanConfValue(USE_DC,
			   (gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dccheck)));
	setBooleanConfValue(USE_CONTENT,
			   (gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(contentcheck)));
	setBooleanConfValue(USE_SLASH,
			   (gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(slashcheck)));
	/* reinitialize */
	loadConfig();
	initBackend();
			
	gtk_widget_hide(prefdialog);
}

void on_aboutbtn_clicked(GtkButton *button, gpointer user_data) {
	if(NULL == aboutdialog || !G_IS_OBJECT(aboutdialog))
		aboutdialog = create_aboutdialog ();		

	gtk_widget_show(aboutdialog);
}

void on_deletebtn(GtkWidget *feedlist) {
	gpointer		cp;

	/* user_data has to contain the feed list widget reference */
	cp = getFeedViewSelection(feedlist);
	
	/* make sure thats no grouping iterator */
	if(NULL != cp) {
		print_status(g_strdup_printf("%s %s",_("Deleting feed"), getFeedTitle(cp)));
		removeFeed(cp);
		
		clearItems();
	} else {
		print_status(_("Error: Cannot delete this list entry!"));
	}
}

void on_popup_delete_selected(void) {
	on_deletebtn(lookup_widget(mainwindow, "feedlist"));
}

void on_deletebtn_clicked(GtkButton *button, gpointer user_data) {
	on_deletebtn(lookup_widget(feedlistdialog, "feedlist"));
}

void on_flupbtn_clicked(GtkButton *button, gpointer user_data) {
	gpointer		cp;
	
	/* user_data has to contain the feed list widget reference */
	cp = getFeedViewSelection(GTK_WIDGET(lookup_widget(feedlistdialog, "feedlist")));
	
	/* make sure thats no grouping iterator */
	if(NULL != cp) {
		print_status(g_strdup_printf("%s \"%s\"",_("Moving feed up"), getFeedTitle(cp))); // FIXME: g_free...
		moveUpFeedPosition(cp);	
		
		selectFeedViewItem(mainwindow, "feedlist", cp);		
		selectFeedViewItem(feedlistdialog, "feedlist", cp);
	} else {
		print_status(_("Error: Cannot move up this list entry!"));
        }
}



void on_fldownbtn_clicked(GtkButton *button, gpointer user_data) {
	gpointer		cp;

	/* user_data has to contain the feed list widget reference */
	cp = getFeedViewSelection(GTK_WIDGET(lookup_widget(feedlistdialog, "feedlist")));
	
	/* make sure thats no grouping iterator */
	if(NULL != cp) {
		print_status(g_strdup_printf("%s \"%s\"",_("Moving feed down"), getFeedTitle(cp))); // FIXME: g_free...
		moveDownFeedPosition(cp);
		
		selectFeedViewItem(feedlistdialog, "feedlist", cp);
		selectFeedViewItem(mainwindow, "feedlist", cp);
	} else {
		print_status(_("Error: Cannot move down this list entry!"));
	}
}

void on_flsortbtn_clicked(GtkButton *button, gpointer user_data) {

	print_status(_("Sorting not yet implemented!\n"));
	sortFeeds();
}

void on_propbtn(GtkWidget *feedlist) {
	gpointer	cp;
	GtkWidget 	*feednameentry;
	GtkWidget 	*feedurlentry;
	
	/* user_data has to contain the feed list widget reference */
	if(NULL == (cp = getFeedViewSelection(feedlist))) {
		print_status(_("Internal Error! Feed pointer NULL!\n"));
		return;
	}

	if(NULL == propdialog || !G_IS_OBJECT(propdialog))
		propdialog = create_propdialog();

	feednameentry = lookup_widget(propdialog, "feednameentry");
	feedurlentry = lookup_widget(propdialog, "feedurlentry");
g_print("ttitle:%s sourc:%s\n",getFeedTitle(cp),getFeedSource(cp));	
	gtk_entry_set_text(GTK_ENTRY(feednameentry), getFeedTitle(cp));
	gtk_entry_set_text(GTK_ENTRY(feedurlentry), getFeedSource(cp));

	/* note: the OK buttons signal is connected on the fly
	   to pass the correct dialog widget that feedlist was
	   clicked... */

	g_signal_connect((gpointer)lookup_widget(propdialog, "propchangebtn"), 
			 "clicked", G_CALLBACK (on_propchangebtn_clicked), feedlist);
   
	   
	gtk_widget_show(propdialog);
}

void on_propchangebtn_clicked(GtkButton *button, gpointer user_data) {
	gpointer	cp;

	if(NULL != (cp = getFeedViewSelection(GTK_WIDGET(user_data)))) {
		GtkWidget *feednameentry = lookup_widget(propdialog, "feednameentry");
		GtkWidget *feedurlentry = lookup_widget(propdialog, "feedurlentry");

		gchar *feedurl = (gchar *)gtk_entry_get_text(GTK_ENTRY(feedurlentry));
		gchar *feedname = (gchar *)gtk_entry_get_text(GTK_ENTRY(feednameentry));

		setFeedTitle(cp, feedname);    
		setFeedURL(cp, feedurl);
		updateFeed(cp);

		selectFeedViewItem(feedlistdialog, "feedlist", cp);
		selectFeedViewItem(mainwindow, "feedlist", cp);
	}
}

void on_popup_prop_selected(void) {

	g_assert(NULL != mainwindow);
	on_propbtn(GTK_WIDGET(lookup_widget(mainwindow, "feedlist")));
}

void on_propbtn_clicked(GtkButton *button, gpointer user_data) {

	g_assert(NULL != feedlistdialog);
	on_propbtn(GTK_WIDGET(lookup_widget(feedlistdialog, "feedlist")));
}

void on_newbtn_clicked(GtkButton *button, gpointer user_data) {	
	GtkWidget *feedurlentry;
	GtkWidget *feednameentry;

	if(NULL == newdialog || !G_IS_OBJECT(newdialog)) 
		newdialog = create_newdialog();

	if(NULL == feednamedialog || !G_IS_OBJECT(feednamedialog)) 
		feednamedialog = create_feednamedialog();

	/* always clear the edit field */
	feedurlentry = lookup_widget(newdialog, "newfeedentry");
	gtk_entry_set_text(GTK_ENTRY(feedurlentry), "");	

	gtk_widget_show(newdialog);
}

void on_newfeedbtn_clicked(GtkButton *button, gpointer user_data) {
	GtkWidget *feedurlentry = lookup_widget(newdialog, "newfeedentry");
	GtkWidget *feednameentry = lookup_widget(feednamedialog, "feednameentry");
	gchar	*feedurl = (gchar *)gtk_entry_get_text(GTK_ENTRY(feedurlentry));

	if(0 == newFeed(NULL, feedurl, TRUE, TRUE)) {

		/* note: we assume that the feed created by newFeed() in
		   is the actual selected feed so we can get its default title */

		gtk_entry_set_text(GTK_ENTRY(feednameentry), getDefaultFeedTitle(NULL));

		gtk_widget_show(feednamedialog);
	}
}

void on_feednamebutton_clicked(GtkButton *button, gpointer user_data) {	
	GtkWidget *feednameentry = lookup_widget(feednamedialog, "feednameentry");
	GtkWidget *feedurlentry = lookup_widget(newdialog, "newfeedentry");
	
	gchar *feedurl = (gchar *)gtk_entry_get_text(GTK_ENTRY(feedurlentry));
	gchar *feedname = (gchar *)gtk_entry_get_text(GTK_ENTRY(feednameentry));

	/* note: we assume that the feed created by newFeed() in
	   on_newfeedbtn_clicked() is the actual selected feed */
	setFeedTitle(NULL, feedname);
}

void feedlist_selection_changed_cb(GtkTreeSelection *selection, gpointer data) {
	GtkWidget		*itemlist;
	GtkTreeSelection	*itemselection;
	GtkTreeIter		iter;
        GtkTreeModel		*model;
	gpointer		cp;

        if (gtk_tree_selection_get_selected (selection, &model, &iter))
        {
                gtk_tree_model_get (model, &iter, 
				FS_CP, &cp,
				-1);

		/* make sure thats no grouping iterator */
		if(NULL != cp) {
			loadItems(cp);
			showFeedInfo(cp);		
		}		
        }
}

void itemlist_selection_changed_cb (GtkTreeSelection *selection, gpointer data) {
	GtkWidget	*textview;
	GtkTreeIter	iter;
        GtkTreeModel	*model;
        gchar		*title;
        gchar		*link;	
	gpointer	ip;
	gpointer	cp;

	cp = getFeedViewSelection(GTK_WIDGET(data));
	
        if (gtk_tree_selection_get_selected (selection, &model, &iter))
        {
                gtk_tree_model_get (model, &iter, 
				IS_PTR, &ip,
				-1);
		
		g_assert(ip != NULL);
		
		showItem(ip, cp);
		markItemAsRead(ip, &iter);
        }
}

/* set up the feed list store and connects it to the feed list
   view in the main window */
void setupFeedList(GtkWidget *mainview) {
	GtkCellRenderer		*renderer;
	GtkTreeViewColumn 	*column;
	GtkTreeSelection	*select;	
	GtkTreeIter		*iter;
	GtkTreeStore		*feedstore;
	
	feedstore = getFeedStore();

	gtk_tree_view_set_model(GTK_TREE_VIEW(mainview), GTK_TREE_MODEL(feedstore));
	
	/* we only render the state and title */
	renderer = gtk_cell_renderer_pixbuf_new();
	column = gtk_tree_view_column_new_with_attributes("", renderer, "pixbuf", FS_STATE, NULL);	
	gtk_tree_view_append_column(GTK_TREE_VIEW(mainview), column);

	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes(_("Title"), renderer, "text", FS_TITLE, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(mainview), column);
	/* gtk_tree_view_column_set_sort_column_id(column, FS_TITLE); */


	/* prepare feed list groups */	
/*	if(NULL == (iter = (GtkTreeIter *)g_malloc(sizeof(GtkTreeIter)))) 
		g_error("could not allocate memory!\n");

	gtk_tree_store_append(feedstore, iter, NULL);
	gtk_tree_store_set(feedstore, iter, FS_TITLE, _("my feeds"),
					    FS_STATE, NULL,
					    FS_URL, NULL,
					    -1);
	myfeedgroup = iter;

	if(NULL == (iter = (GtkTreeIter *)g_malloc(sizeof(GtkTreeIter)))) 
		g_error("could not allocate memory!\n");

	gtk_tree_store_append(feedstore, iter, NULL);
	gtk_tree_store_set(feedstore, iter, FS_TITLE, _("available feeds"),
					    FS_STATE, NULL,
					    FS_URL, NULL,
					    -1);	
	availablefeedgroup = iter;*/
		
	/* Setup the selection handler for the main view */
	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(mainview));
	gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
	g_signal_connect(G_OBJECT(select), "changed",
                 	 G_CALLBACK(feedlist_selection_changed_cb),
                	 lookup_widget(mainwindow, "feedlist"));
}

static void func_text(GtkTreeViewColumn *tree_column,
	             GtkCellRenderer   *cell,
	             GtkTreeModel      *model,
        	     GtkTreeIter       *iter,
	             gpointer           data)
{
	GdkPixbuf	*tmp_state;

	gtk_tree_model_get(model, iter, IS_STATE, &tmp_state, -1);
	if(tmp_state == unreadIcon) {
		g_object_set(GTK_CELL_RENDERER(cell), "font", "bold", NULL);
	} else {
		g_object_set(GTK_CELL_RENDERER(cell), "font", "normal", NULL);
	}
}

void setupItemList(GtkWidget *itemlist) {
	GtkCellRenderer		*renderer;
	GtkTreeViewColumn 	*column;
	GtkTreeSelection	*select;
	GtkTreeStore		*itemstore;	
	
	itemstore = getItemStore();

	gtk_tree_view_set_model(GTK_TREE_VIEW(itemlist), GTK_TREE_MODEL(itemstore));

	/* we only render the state, title and time */
	renderer = gtk_cell_renderer_pixbuf_new();
	column = gtk_tree_view_column_new_with_attributes("", renderer, "pixbuf", IS_STATE, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(itemlist), column);
	/*gtk_tree_view_column_set_sort_column_id(column, IS_STATE); ...leads to segfaults on tab-bing through */

	renderer = gtk_cell_renderer_text_new();
	column = gtk_tree_view_column_new_with_attributes(_("Time"), renderer, "text", IS_TIME, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(itemlist), column);
	gtk_tree_view_column_set_sort_column_id(column, IS_TIME);
						
	renderer = gtk_cell_renderer_text_new();						   	
	column = gtk_tree_view_column_new_with_attributes(_("Title"), renderer, "text", IS_TITLE, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(itemlist), column);
	gtk_tree_view_column_set_sort_column_id(column, IS_TITLE);
	
	gtk_tree_view_column_set_cell_data_func (column, renderer,
                                           func_text, NULL, NULL);

	/* Setup the selection handler */
	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(itemlist));
	gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
	g_signal_connect(G_OBJECT(select), "changed",
                  G_CALLBACK(itemlist_selection_changed_cb),
                  lookup_widget(mainwindow, "feedlist"));
	
}

static GtkMenu *make_menu(void) {
	GtkWidget *menu, *item;
	gchar *caption;

	menu = gtk_menu_new(); 

	item = gtk_menu_item_new_with_label(_("update feed"));
	gtk_signal_connect(GTK_OBJECT(item), "activate",
		     GTK_SIGNAL_FUNC(on_popup_refresh_selected), NULL);
	gtk_menu_append(GTK_MENU(menu), item);
	gtk_widget_show(item);	

	item = gtk_menu_item_new_with_label(_("add feed"));
	gtk_signal_connect(GTK_OBJECT(item), "activate",
		     GTK_SIGNAL_FUNC(on_newbtn_clicked), NULL);
	gtk_menu_append(GTK_MENU(menu), item);
	gtk_widget_show(item);

	item = gtk_menu_item_new_with_label(_("remove feed"));
	gtk_signal_connect(GTK_OBJECT(item), "activate",
		     GTK_SIGNAL_FUNC(on_popup_delete_selected), NULL);
	gtk_menu_append(GTK_MENU(menu), item);
	gtk_widget_show(item);

// FIXME: the url string in the property dialog points to invalid address
/*	item = gtk_menu_item_new_with_label(_("feed properties"));
	gtk_signal_connect(GTK_OBJECT(item), "activate",
		     GTK_SIGNAL_FUNC(on_popup_prop_selected), NULL);
	gtk_menu_append(GTK_MENU(menu), item);
	gtk_widget_show(item);*/

	return GTK_MENU(menu);
}

gboolean on_mainfeedlist_button_press_event(GtkWidget *widget,
					    GdkEventButton *event,
                                            gpointer user_data)
{
	GdkEventButton *eb;
	gboolean retval;
  
	if (event->type != GDK_BUTTON_PRESS) return FALSE;
	eb = (GdkEventButton*) event;

	if (eb->button != 3)
		return FALSE;

	gtk_menu_popup(make_menu(), NULL, NULL, NULL, NULL,
			 eb->button, eb->time);
	return TRUE;
}

/* write text to statusbar */
void print_status (gchar *statustext) {
	GtkWidget *statusbar = lookup_widget(mainwindow, "statusbar");

	g_print("%s\n", statustext);
	gtk_label_set_text(GTK_LABEL(GTK_STATUSBAR(statusbar)->label), 
			    statustext);
}
